@@ -1,5 +1,5 @@
 use {
-    crate::{state::*, errors::*},
+    crate::{state::*, errors::ErrorCode},
     anchor_lang::{prelude::*},
     anchor_spl::{token::{TokenAccount}},
     cardinal_token_manager::{state::TokenManager},
@@ -10,7 +10,7 @@ use {
 pub struct IncrementUsagesCtx<'info> {
     token_manager: Box<Account<'info, TokenManager>>,
 
-    #[account(mut, constraint = use_invalidator.max_usages == None || use_invalidator.usages + num_usages <= use_invalidator.max_usages.unwrap() @ ErrorCode::InsufficientUsages)]
+    #[account(mut, constraint = use_invalidator.total_usages == None || use_invalidator.usages + num_usages <= use_invalidator.total_usages.unwrap() @ ErrorCode::InsufficientUsages)]
     use_invalidator: Box<Account<'info, UseInvalidator>>,
 
     #[account(constraint = token_manager.recipient_token_account == recipient_token_account.key() @ ErrorCode::InvalidTokenAccount)]
@@ -19,7 +19,7 @@ pub struct IncrementUsagesCtx<'info> {
     user: Signer<'info>,
 }
 
-pub fn handler(ctx: Context<IncrementUsagesCtx>, num_usages: u64) -> ProgramResult {
+pub fn handler(ctx: Context<IncrementUsagesCtx>, num_usages: u64) -> Result<()> {
     let use_invalidator = &mut ctx.accounts.use_invalidator;
     use_invalidator.usages += num_usages;
     return Ok(())
